from .template import Template


class Orders():
    """
    Orders - таблица с заказами
    """

    # ID METASERVICE
    id_metaservice = Template.id_metaservice

    # DATA
    status = models.CharField(
        max_length=150,
        help_text="текущий статус заказа из возможных на платформе"
    )
    title = models.CharField(
        max_length=150,
        help_text="заголовок заказа",
        default='Заголовок'
    )
    note = models.CharField(
        max_length=150,
        help_text="задание к заказу",
        default='Записи'
    )
    time_created = models.DateTimeField(
        auto_now_add=True,
        help_text="время создания заказа"
    )
    time_placed = models.DateTimeField(
        help_text="время размещения заказа"
    )
    time_start = models.DateTimeField(
        null=True,
        help_text="время начала оказания услуги"
    )
    time_start_real = models.DateTimeField(
        null=True,
        help_text=""
    )
    time_start_predicted = models.DateTimeField(
        null=True,
        help_text=""
    )
    time_finish_real = models.DateTimeField(
        null=True,
        help_text="фактическое время окончания (точное установленное время)"
    )
    time_finish_predicted = models.DateTimeField(
        help_text="предварительное/расчетное время до окончания оказания услуги"
    )
    real_price = models.FloatField(
        help_text="цена с учетом тарифа поставщика услуг по факту оказания услуги"
    )
    predicted_price = models.FloatField(
        help_text="расчетная цена с учетом тарифа поставщика услуг"
    )
    asap = models.BooleanField(
        default=False,
        help_text="Срочный ли заказ"
    )

    # OTHER
    is_global = Template.is_global
    is_visible = Template.is_visible

    # FK
    ticket = models.ForeignKey(
        Ticket,
        null=True,
        on_delete=models.DO_NOTHING
    )
    service = models.ForeignKey(
        Service,
        null=True,
        on_delete=models.DO_NOTHING,
        help_text="спецификатор услуги провайдера, нужен для установления цены (id_service - уникальный идентификатор шаблона услуги, необходим для установления цены и исполнителей."
    )
    service_type = models.ForeignKey(
        ServiceType,
        null=True,
        on_delete=models.DO_NOTHING,
        help_text="тип заказа по классификатору услу"
    )
    client = models.ForeignKey(
        Client,
        null=True,
        on_delete=models.DO_NOTHING,
        help_text="клиент/аккаунт, который оплачивает все оказанные услуги"
    )
    provider = models.ForeignKey(
        Provider,
        null=True,
        on_delete=models.DO_NOTHING,
        help_text="уникальный идентификатор поставщика услуги/аккаунта, который оказывает услугу. Если несколько провайдеров собираются мета-сервисом в цепочку, где на уровне связи с клиентом нельзя установить одно ответственное лицо, то указывается вспомогательный мета-провайдер сервиса, и это означает, что мета-сервис несет ответственность перед пользователем за сборку услуги воедино."
    )
    receiver = models.ForeignKey(
        get_user_model(),
        null=True,
        related_name="user_id",
        on_delete=models.DO_NOTHING,
        help_text="пользователь/аккаунт, который принимает оказываемые услуги"
    )
    company = models.ForeignKey(
        Company,
        on_delete=models.DO_NOTHING,
        null=True,
        help_text="Идентификатор компании, к которой относится документ, если таковая есть (может не быть)"
    )
